==> certmanager-model-v1alpha2-6.0.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderAzureDNSBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderAzureDNSBuilder extends ACMEIssuerDNS01ProviderAzureDNSFluentImpl<ACMEIssuerDNS01ProviderAzureDNSBuilder> implements VisitableBuilder<ACMEIssuerDNS01ProviderAzureDNS,ACMEIssuerDNS01ProviderAzureDNSBuilder>{
  public ACMEIssuerDNS01ProviderAzureDNSBuilder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderAzureDNS(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNSFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNSFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderAzureDNS(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNSFluent<?> fluent,ACMEIssuerDNS01ProviderAzureDNS instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNSFluent<?> fluent,ACMEIssuerDNS01ProviderAzureDNS instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withClientID(instance.getClientID()); 
    fluent.withClientSecretSecretRef(instance.getClientSecretSecretRef()); 
    fluent.withEnvironment(instance.getEnvironment()); 
    fluent.withHostedZoneName(instance.getHostedZoneName()); 
    fluent.withResourceGroupName(instance.getResourceGroupName()); 
    fluent.withSubscriptionID(instance.getSubscriptionID()); 
    fluent.withTenantID(instance.getTenantID()); 
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNS instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNS instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withClientID(instance.getClientID()); 
    this.withClientSecretSecretRef(instance.getClientSecretSecretRef()); 
    this.withEnvironment(instance.getEnvironment()); 
    this.withHostedZoneName(instance.getHostedZoneName()); 
    this.withResourceGroupName(instance.getResourceGroupName()); 
    this.withSubscriptionID(instance.getSubscriptionID()); 
    this.withTenantID(instance.getTenantID()); 
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderAzureDNSFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderAzureDNS build() {
    ACMEIssuerDNS01ProviderAzureDNS buildable = new ACMEIssuerDNS01ProviderAzureDNS(fluent.getClientID(),fluent.getClientSecretSecretRef(),fluent.getEnvironment(),fluent.getHostedZoneName(),fluent.getResourceGroupName(),fluent.getSubscriptionID(),fluent.getTenantID());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.6.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderAzureDNSBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderAzureDNSBuilder extends ACMEIssuerDNS01ProviderAzureDNSFluentImpl<ACMEIssuerDNS01ProviderAzureDNSBuilder> implements VisitableBuilder<ACMEIssuerDNS01ProviderAzureDNS,ACMEIssuerDNS01ProviderAzureDNSBuilder>{
  public ACMEIssuerDNS01ProviderAzureDNSBuilder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderAzureDNS(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNSFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNSFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderAzureDNS(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNSFluent<?> fluent,ACMEIssuerDNS01ProviderAzureDNS instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNSFluent<?> fluent,ACMEIssuerDNS01ProviderAzureDNS instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withClientID(instance.getClientID()); 
    fluent.withClientSecretSecretRef(instance.getClientSecretSecretRef()); 
    fluent.withEnvironment(instance.getEnvironment()); 
    fluent.withHostedZoneName(instance.getHostedZoneName()); 
    fluent.withManagedIdentity(instance.getManagedIdentity()); 
    fluent.withResourceGroupName(instance.getResourceGroupName()); 
    fluent.withSubscriptionID(instance.getSubscriptionID()); 
    fluent.withTenantID(instance.getTenantID()); 
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNS instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderAzureDNSBuilder(ACMEIssuerDNS01ProviderAzureDNS instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withClientID(instance.getClientID()); 
    this.withClientSecretSecretRef(instance.getClientSecretSecretRef()); 
    this.withEnvironment(instance.getEnvironment()); 
    this.withHostedZoneName(instance.getHostedZoneName()); 
    this.withManagedIdentity(instance.getManagedIdentity()); 
    this.withResourceGroupName(instance.getResourceGroupName()); 
    this.withSubscriptionID(instance.getSubscriptionID()); 
    this.withTenantID(instance.getTenantID()); 
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderAzureDNSFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderAzureDNS build() {
    ACMEIssuerDNS01ProviderAzureDNS buildable = new ACMEIssuerDNS01ProviderAzureDNS(fluent.getClientID(),fluent.getClientSecretSecretRef(),fluent.getEnvironment(),fluent.getHostedZoneName(),fluent.getManagedIdentity(),fluent.getResourceGroupName(),fluent.getSubscriptionID(),fluent.getTenantID());
    return buildable;
  }
  
}
